Package: rsamplr
Title: Sampling Algorithms and Spatially Balanced Sampling
Version: 0.2.0
Authors@R: c(
    person("Wilmer", "Prentius", , "wilmer.prentius@slu.se",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-3561-290X")),
    person("Anton", "Grafström", role = "ctb",
           comment = c(ORCID = "0000-0002-4345-4024")),
    person("Authors of the dependent Rust crates", role = "aut",
           comment = "see inst/AUTHORS file")
  )
Description: 
    Fast tools for unequal probability sampling in multi-dimensional spaces, implemented in Rust for high performance.
    The package offers a wide range of methods, including Sampford (Sampford, 1967, <doi:10.1093/biomet/54.3-4.499>) and correlated Poisson sampling (Bondesson and Thorburn, 2008, <doi:10.1111/j.1467-9469.2008.00596.x>), pivotal sampling (Deville and Tillé, 1998, <doi:10.1093/biomet/91.4.893>), and balanced sampling such as the cube method (Deville and Tillé, 2004, <doi:10.1093/biomet/91.4.893>) to ensure auxiliary totals are respected.
    Spatially balanced approaches, including the local pivotal method (Grafström et al., 2012, <doi:10.1111/j.1541-0420.2011.01699.x>), spatially correlated Poisson sampling (Grafström, 2012, <doi:10.1016/j.jspi.2011.07.003>), and locally correlated Poisson sampling (Prentius, 2024, <doi:10.1002/env.2832>), provide efficient designs when the target variable is linked to auxiliary information.
URL: https://www.envisim.se/, https://github.com/envisim/rust-samplr/
BugReports: https://github.com/envisim/rust-samplr/issues
License: AGPL-3
Encoding: UTF-8
Language: en-GB
Depends: R (>= 4.5)
RoxygenNote: 7.3.3
SystemRequirements: Cargo (Rust's package manager), rustc >= 1.84.1
NeedsCompilation: yes
Packaged: 2026-03-30 14:57:44 UTC; wpmg
Author: Wilmer Prentius [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3561-290X>),
  Anton Grafström [ctb] (ORCID: <https://orcid.org/0000-0002-4345-4024>),
  Authors of the dependent Rust crates [aut] (see inst/AUTHORS file)
Maintainer: Wilmer Prentius <wilmer.prentius@slu.se>
Repository: CRAN
Date/Publication: 2026-03-31 06:00:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 22:02:48 UTC; unix
Archs: rsamplr.so.dSYM
