# Generated by roxygen2: do not edit by hand

S3method("$<-",savvy_rsamplr__sealed)
S3method("[[<-",savvy_rsamplr__sealed)
S3method(draw,dbd)
export(balance_deviation)
export(brewer)
export(conditional_poisson)
export(cps)
export(cube)
export(cube_stratified)
export(dbd_circular)
export(dbd_circular_iter)
export(dbd_tc)
export(dbd_tc_iter)
export(draw)
export(lcps)
export(local_cube)
export(local_cube_stratified)
export(local_mean_variance)
export(lpm_1)
export(lpm_1s)
export(lpm_2)
export(lpm_2_hierarchical)
export(pareto)
export(pips_from_vector)
export(poisson)
export(rpm)
export(sampford)
export(sample_to_indicator)
export(scps)
export(spatial_balance_all)
export(spatial_balance_all_equal)
export(spatial_balance_energy)
export(spatial_balance_energy_equal)
export(spatial_balance_local)
export(spatial_balance_local_equal)
export(spatial_balance_voronoi)
export(spatial_balance_voronoi_equal)
export(spm)
export(systematic)
export(systematic_random_order)
useDynLib(rsamplr, .registration = TRUE)
