# Authors of vendored cargo crates
- cc 1.2.58: Alex Crichton
- envisim_estimate 0.4.0: Wilmer Prentius
- envisim_samplr 0.5.0: Wilmer Prentius
- envisim_utils 0.4.0: Wilmer Prentius
- proc-macro2 1.0.106: David Tolnay, Alex Crichton
- quote 1.0.45: David Tolnay
- rustc-hash 2.1.2: The Rust Project Developers
- savvy 0.9.2: Hiroaki Yutani
- savvy-bindgen 0.9.2: Hiroaki Yutani
- savvy-ffi 0.9.2: Hiroaki Yutani
- savvy-macro 0.9.2: Hiroaki Yutani
- shlex 1.3.0: comex, Fenhl, Adrian Taylor, Alex Touchet, Daniel Parks, Garrett Berg
- syn 2.0.117: David Tolnay
- unicode-ident 1.0.24: David Tolnay

(This file was auto-generated from 'cargo metadata' on 2026-03-30)
