% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distributional_designs.R
\name{Iterative evaluation of distributional designs}
\alias{Iterative evaluation of distributional designs}
\alias{dbd_circular_iter}
\alias{dbd_tc_iter}
\title{Iterative evaluation of distributional designs}
\usage{
dbd_circular_iter(sample_size, spread_mat, ...)

dbd_tc_iter(sample_size, spread_mat, ...)
}
\arguments{
\item{sample_size}{The size of the desired sample.}

\item{spread_mat}{A matrix of spreading covariates.}

\item{...}{Additional arguments, see \code{\link[=.dbd_defaults]{.dbd_defaults()}}.
Note:
\itemize{
\item \code{max_iter} determines the number of iterations to run;
\item \code{iter_by} determines the reporting interval.
}}
}
\value{
A matrix with the average energies and the standard deviations of the energies as
columns, per the reporting intervals.
}
\description{
Evaluates the energy distance along a simulated annealing scheme.
}
\section{Functions}{
\itemize{
\item \code{dbd_tc_iter()}: Iterative evolution of distributional design using
Tactical Configuration

}}
\examples{
set.seed(12345);
N = 1000L;
n = 100L;
prob = rep(n / N, N);
xs = matrix(runif(N * 2), ncol = 2);

# Report mean and sd energy at every 1e4L iteration
dbd_circular_iter(
  n,
  xs,
  annealing_temp = 0.1,
  annealing_cooling = 0.999,
  max_iter = 1e5L,
  iter_by = 1e4L
);

# Report mean and sd energy at every 1e4L iteration
dbd_tc_iter(
  n,
  xs,
  annealing_temp = 0.1,
  annealing_cooling = 0.999,
  max_iter = 1e5L,
  iter_by = 1e4L
);

}
